Set of tools to use with OpenFAST:

- postprocessing of outputs
- generation of cases
- running cases
- linearization postprocessing
- scripts specific to some modules: beamdyn, hydrodyn, olaf, subdyn, fastfarm


Some of it was ported to "pyFAST", the python-toolbox of OpenFAST, but latest version are typically found here.
